#!/usr/bin/env python3

import json
import requests
import os
import sys
from datetime import datetime
from zoneinfo import ZoneInfo

ICON_MAP = {
    "01d": "☀️",
    "02d": "⛅️",
    "03d": "☁️",
    "04d": "☁️",
    "09d": "🌧️",
    "10d": "🌦️",
    "11d": "⛈️",
    "13d": "🌨️",
    "50d": "🌫",
}


def main():
    apikey = os.getenv("WAYBAR_WEATHER_APIKEY")
    weather_lat = os.getenv("WAYBAR_WEATHER_LAT", "52.52")
    weather_lon = os.getenv("WAYBAR_WEATHER_LON", "13.38")
    weather_units = os.getenv("WAYBAR_WEATHER_UNITS", "metric")
    weather_exclude = os.getenv("WAYBAR_WEATHER_EXCLUDE", "minutely,daily")

    data = {}
    try:
        weather = requests.get(
            "https://api.openweathermap.org/data/2.5/onecall?lat={lat}&lon={lon}&units={units}&exclude={exclude}&appid={apikey}".format(
                **{
                    "apikey": apikey,
                    "lat": weather_lat,
                    "lon": weather_lon,
                    "units": weather_units,
                    "exclude": weather_exclude,
                }
            )
        ).json()
    except Exception as e:
        return print({})

    if weather.get("cod"):
        data["text"] = "[weather] Error {}: {}".format(
            weather.get("cod"), weather.get("message")
        )
        data["class"] = "weather"
        print(json.dumps(data))
        # sys.exit(data["text"])
        sys.exit()

    temp = weather["current"]["temp"]
    icon = ICON_MAP.get(weather["current"]["weather"][0]["icon"], "")
    feels_like = weather["current"]["feels_like"]
    humidity = weather["current"]["humidity"]
    pressure = weather["current"]["pressure"]
    sunrise = datetime.fromtimestamp(
        weather["current"]["sunrise"], ZoneInfo(weather["timezone"])
    ).strftime("%H:%M")
    sunset = datetime.fromtimestamp(
        weather["current"]["sunset"], ZoneInfo(weather["timezone"])
    ).strftime("%H:%M")
    wind_speed = weather["current"]["wind_speed"]

    data["text"] = "{0} {1}°C".format(icon, temp)
    data[
        "tooltip"
    ] = """Feels like {0}°C
Pressure {1}
Humidity {2}
Sunrise {3}
Sunset {4}
Wind speed {5}Km/h
    """.format(
        feels_like, pressure, humidity, sunrise, sunset, wind_speed
    )
    data["class"] = "weather"

    print(json.dumps(data))


if __name__ == "__main__":
    main()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['waybar_openweathermap']

package_data = \
{'': ['*']}

install_requires = \
['geopy>=2.2.0,<3.0.0']

entry_points = \
{'console_scripts': ['waybar-openweathermap = waybar_openweathermap:main']}

setup_kwargs = {
    'name': 'waybar-openweathermap',
    'version': '1.0.2',
    'description': 'Weather info widget for Waybar, from OpenWeatherMap.org',
    'long_description': 'Waybar weather plugin\n=====================\n\nThis plugin uses the [One Call API from OpenWeatherMap.org](https://openweathermap.org/api/one-call-api).\n\n## set your APIKEY and geo location in your shell\n\nIn your ~/.bashrc add the following definition and place your APIKEY in there\n\n    # waybar weather settings:\n    export WAYBAR_WEATHER_APIKEY="<YOUR OpenWeatherMap API KEY>"\n    export WAYBAR_WEATHER_LAT="44.43"\n    export WAYBAR_WEATHER_LON="26.02"\n    export WAYBAR_WEATHER_UNITS="metric"\n    export WAYBAR_WEATHER_EXCLUDE="minutely,hourly,daily"',
    'author': 'Maik Derstappen - Derico',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/MrTango/waybar-openweathermap',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
